Authors and Contributors
===========

BETSE is principally authored by [Alexis
Pietak](https://www.researchgate.net/profile/Alexis_Pietak) and [Cecil
Curry](https://gitlab.com/u/leycec) with **much-appreciated contributions**
from (_in chronological order of first merge request_):

* [**Douglas Moore**](https://gitlab.com/u/dglmoore) for:
  * [REPL and scripting support](https://gitlab.com/betse/betse/merge_requests/2).
  * [Windows integration](https://gitlab.com/betse/betse/merge_requests/1).

A rousing thanks to these illustrious contributors, without whom BETSE would
only be a dim glimmer in the undocumented shallows of GitLab. **You are
uniformly awesome. <sup>*</sup>**

<sup>* _As evidenced by this footnote, we really mean it._</sup>

## GitLab

For an HTML5-driven topology of all contributors, see our [Contributors
Graph](https://gitlab.com/betse/betse/graphs/master/contributors).

## Git

For a CLI-driven list of all contributions to filename `${filename}` by:

* High-level **commits** (tracked across file renames), run the following command in
  local copies of BETSE's Git repository:

        git log --follow ${filename}

* Low-level **line numbers**,  run the following command in the same:

        git blame ${filename}
